<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$pageTitle = "Nuevo Crédito";

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $db = Database::getInstance()->getConnection();
        $db->beginTransaction();

        // Validar y sanitizar datos
        $customerName = sanitize($_POST['customer_name']);
        $customerContact = sanitize($_POST['customer_contact']);
        $totalAmount = filter_var($_POST['total_amount'], FILTER_VALIDATE_FLOAT);
        $numInstallments = filter_var($_POST['num_installments'], FILTER_VALIDATE_INT);
        $startDate = $_POST['start_date'];

        // Validaciones
        $errors = [];
        if (empty($customerName)) {
            $errors[] = "El nombre del cliente es requerido.";
        }
        if (!$totalAmount || $totalAmount <= 0) {
            $errors[] = "El monto total debe ser mayor a 0.";
        }
        if (!in_array($numInstallments, INSTALLMENT_OPTIONS)) {
            $errors[] = "El número de cuotas no es válido.";
        }
        if (!strtotime($startDate)) {
            $errors[] = "La fecha de inicio no es válida.";
        }

        if (empty($errors)) {
            // Insertar o actualizar cliente
            $stmt = $db->prepare("SELECT id FROM customers WHERE name = ?");
            $stmt->execute([$customerName]);
            $customer = $stmt->fetch();

            if ($customer) {
                $customerId = $customer['id'];
                // Actualizar contacto si es diferente
                $stmt = $db->prepare("UPDATE customers SET contact = ? WHERE id = ?");
                $stmt->execute([$customerContact, $customerId]);
            } else {
                $stmt = $db->prepare("INSERT INTO customers (name, contact) VALUES (?, ?)");
                $stmt->execute([$customerName, $customerContact]);
                $customerId = $db->lastInsertId();
            }

            // Insertar crédito
            $stmt = $db->prepare("
                INSERT INTO credits 
                (customer_id, total_amount, num_installments, start_date, outstanding_balance) 
                VALUES (?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $customerId,
                $totalAmount,
                $numInstallments,
                $startDate,
                $totalAmount // Saldo inicial igual al monto total
            ]);

            $db->commit();
            $successMessage = "Crédito creado exitosamente.";
            redirect('index.php');
        }
    } catch (Exception $e) {
        $db->rollBack();
        error_log("Error en add_credit.php: " . $e->getMessage());
        $errorMessage = "Ha ocurrido un error al crear el crédito. Por favor, intente nuevamente.";
    }
}

require_once 'templates/header.php';
?>

<div class="bg-white rounded-lg shadow-md p-6 max-w-2xl mx-auto">
    <div class="flex items-center justify-between mb-6">
        <h1 class="text-2xl font-semibold text-gray-800">
            <i class="fas fa-plus-circle mr-2"></i>Nuevo Crédito
        </h1>
        <a href="index.php" class="text-blue-500 hover:text-blue-600">
            <i class="fas fa-arrow-left mr-1"></i>Volver
        </a>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
            <p class="font-bold">Por favor corrija los siguientes errores:</p>
            <ul class="list-disc list-inside">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <form action="add_credit.php" method="POST" class="space-y-6" data-validate>
        <!-- Datos del Cliente -->
        <div class="bg-gray-50 p-4 rounded-lg">
            <h2 class="text-lg font-medium text-gray-800 mb-4">Datos del Cliente</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <label for="customer_name" class="block text-sm font-medium text-gray-700 mb-1">
                        Nombre del Cliente <span class="text-red-500">*</span>
                    </label>
                    <input type="text" 
                           id="customer_name" 
                           name="customer_name" 
                           required
                           value="<?php echo isset($_POST['customer_name']) ? htmlspecialchars($_POST['customer_name']) : ''; ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
                <div>
                    <label for="customer_contact" class="block text-sm font-medium text-gray-700 mb-1">
                        Contacto
                    </label>
                    <input type="text" 
                           id="customer_contact" 
                           name="customer_contact"
                           value="<?php echo isset($_POST['customer_contact']) ? htmlspecialchars($_POST['customer_contact']) : ''; ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
            </div>
        </div>

        <!-- Datos del Crédito -->
        <div class="bg-gray-50 p-4 rounded-lg">
            <h2 class="text-lg font-medium text-gray-800 mb-4">Datos del Crédito</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <label for="total_amount" class="block text-sm font-medium text-gray-700 mb-1">
                        Monto Total <span class="text-red-500">*</span>
                    </label>
                    <div class="relative">
                        <span class="absolute inset-y-0 left-0 pl-3 flex items-center text-gray-500">$</span>
                        <input type="number" 
                               id="total_amount" 
                               name="total_amount" 
                               required
                               step="0.01"
                               min="0"
                               value="<?php echo isset($_POST['total_amount']) ? htmlspecialchars($_POST['total_amount']) : ''; ?>"
                               class="w-full pl-8 rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                    </div>
                </div>
                <div>
                    <label for="num_installments" class="block text-sm font-medium text-gray-700 mb-1">
                        Número de Cuotas <span class="text-red-500">*</span>
                    </label>
                    <select id="num_installments" 
                            name="num_installments" 
                            required
                            class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                        <option value="">Seleccione...</option>
                        <?php foreach (INSTALLMENT_OPTIONS as $option): ?>
                            <option value="<?php echo $option; ?>" 
                                    <?php echo (isset($_POST['num_installments']) && $_POST['num_installments'] == $option) ? 'selected' : ''; ?>>
                                <?php echo $option; ?> cuotas
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div>
                    <label for="start_date" class="block text-sm font-medium text-gray-700 mb-1">
                        Fecha de Inicio <span class="text-red-500">*</span>
                    </label>
                    <input type="date" 
                           id="start_date" 
                           name="start_date" 
                           required
                           value="<?php echo isset($_POST['start_date']) ? htmlspecialchars($_POST['start_date']) : date('Y-m-d'); ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
            </div>
        </div>

        <div class="flex justify-end space-x-2">
            <a href="index.php" 
               class="px-4 py-2 border border-gray-300 rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                Cancelar
            </a>
            <button type="submit" 
                    class="px-4 py-2 border border-transparent rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                <i class="fas fa-save mr-1"></i> Guardar Crédito
            </button>
        </div>
    </form>
</div>

<!-- Script para calcular y mostrar el valor de la cuota -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    const totalAmountInput = document.getElementById('total_amount');
    const numInstallmentsSelect = document.getElementById('num_installments');
    
    function calculateInstallment() {
        const totalAmount = parseFloat(totalAmountInput.value) || 0;
        const numInstallments = parseInt(numInstallmentsSelect.value) || 1;
        
        if (totalAmount > 0 && numInstallments > 0) {
            const installmentAmount = (totalAmount / numInstallments).toFixed(2);
            document.getElementById('installment_preview').textContent = `$ ${installmentAmount}`;
        }
    }
    
    totalAmountInput.addEventListener('input', calculateInstallment);
    numInstallmentsSelect.addEventListener('change', calculateInstallment);
});
</script>

<?php require_once 'templates/footer.php'; ?>