<?php
require_once 'config.php';
require_once 'db.php';

// Función para sanitizar entrada
function sanitize($data) {
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data, ENT_QUOTES, 'UTF-8');
    return $data;
}

// Función para redireccionar
function redirect($url) {
    header("Location: " . $url);
    exit();
}

// Función para formatear moneda
function formatMoney($amount) {
    return '$ ' . number_format($amount, 2, ',', '.');
}

// Función para formatear fecha
function formatDate($date) {
    return date('d/m/Y', strtotime($date));
}

// Función para calcular estado de cuota
function getInstallmentStatus($dueDate) {
    $today = new DateTime();
    $due = new DateTime($dueDate);
    if ($today > $due) {
        return 'Atrasada';
    }
    return 'Al día';
}

// Función para generar recibo
function generateReceipt($paymentId) {
    $db = Database::getInstance()->getConnection();
    
    try {
        $stmt = $db->prepare("
            SELECT 
                p.payment_date,
                p.payment_amount,
                p.installment_number,
                c.total_amount,
                c.outstanding_balance,
                cu.name as customer_name
            FROM payments p
            JOIN credits c ON p.credit_id = c.id
            JOIN customers cu ON c.customer_id = cu.id
            WHERE p.id = ?
        ");
        
        $stmt->execute([$paymentId]);
        $payment = $stmt->fetch();
        
        if (!$payment) {
            throw new Exception("Pago no encontrado");
        }

        $html = '
        <!DOCTYPE html>
        <html lang="es">
        <head>
            <meta charset="UTF-8">
            <title>Recibo de Pago - ' . COMPANY_NAME . '</title>
            <style>
                @media print {
                    body { margin: 0; padding: 20px; font-family: Arial, sans-serif; }
                    .receipt { max-width: 800px; margin: 0 auto; }
                    .header { text-align: center; margin-bottom: 20px; }
                    .title { font-size: 24px; font-weight: bold; margin: 20px 0; }
                    .logo { max-width: 200px; }
                    .details { margin: 20px 0; }
                    .footer { margin-top: 40px; text-align: center; }
                    table { width: 100%; border-collapse: collapse; margin: 20px 0; }
                    td, th { padding: 8px; border: 1px solid #ddd; }
                }
            </style>
        </head>
        <body>
            <div class="receipt">
                <div class="header">
                    <img src="' . LOGO_URL . '" alt="Logo" class="logo">
                    <h1 class="title">RECIBO</h1>
                    <p>' . COMPANY_NAME . '</p>
                </div>
                <div class="details">
                    <p><strong>Fecha:</strong> ' . formatDate($payment['payment_date']) . '</p>
                    <p><strong>Cliente:</strong> ' . htmlspecialchars($payment['customer_name']) . '</p>
                    <table>
                        <tr>
                            <th>Cuota N°</th>
                            <td>' . $payment['installment_number'] . '</td>
                        </tr>
                        <tr>
                            <th>Monto Pagado</th>
                            <td>' . formatMoney($payment['payment_amount']) . '</td>
                        </tr>
                        <tr>
                            <th>Saldo Pendiente</th>
                            <td>' . formatMoney($payment['outstanding_balance']) . '</td>
                        </tr>
                    </table>
                </div>
                <div class="footer">
                    <p>¡Gracias por su pago!</p>
                </div>
            </div>
            <script>
                window.onload = function() {
                    window.print();
                }
            </script>
        </body>
        </html>';
        
        return $html;
    } catch (Exception $e) {
        error_log("Error generando recibo: " . $e->getMessage());
        return false;
    }
}

// Función para exportar a CSV
function exportToCSV() {
    $db = Database::getInstance()->getConnection();
    
    try {
        // Configurar headers para descarga
        header('Content-Type: text/csv; charset=utf-8');
        header('Content-Disposition: attachment; filename=creditos_' . date('Y-m-d') . '.csv');
        
        // Crear archivo CSV
        $output = fopen('php://output', 'w');
        
        // Escribir BOM para UTF-8
        fprintf($output, chr(0xEF).chr(0xBB).chr(0xBF));
        
        // Encabezados
        fputcsv($output, [
            'ID Crédito',
            'Cliente',
            'Contacto',
            'Monto Total',
            'Cuotas',
            'Saldo Pendiente',
            'Fecha Inicio',
            'Estado'
        ]);
        
        // Consulta para obtener datos
        $query = "
            SELECT 
                c.id,
                cu.name,
                cu.contact,
                c.total_amount,
                c.num_installments,
                c.outstanding_balance,
                c.start_date,
                CASE 
                    WHEN c.outstanding_balance = 0 THEN 'Pagado'
                    ELSE 'Pendiente'
                END as status
            FROM credits c
            JOIN customers cu ON c.customer_id = cu.id
            ORDER BY c.id DESC
        ";
        
        $stmt = $db->query($query);
        while ($row = $stmt->fetch()) {
            fputcsv($output, [
                $row['id'],
                $row['name'],
                $row['contact'],
                $row['total_amount'],
                $row['num_installments'],
                $row['outstanding_balance'],
                $row['start_date'],
                $row['status']
            ]);
        }
        
        fclose($output);
        return true;
    } catch (Exception $e) {
        error_log("Error exportando CSV: " . $e->getMessage());
        return false;
    }
}

// Función para importar desde CSV
function importFromCSV($file) {
    $db = Database::getInstance()->getConnection();
    $results = [
        'success' => 0,
        'errors' => 0,
        'messages' => []
    ];
    
    try {
        if (($handle = fopen($file['tmp_name'], "r")) !== FALSE) {
            $db->beginTransaction();
            
            // Saltar la primera línea (encabezados)
            fgetcsv($handle);
            
            while (($data = fgetcsv($handle)) !== FALSE) {
                try {
                    // Verificar cliente existente o crear nuevo
                    $stmt = $db->prepare("SELECT id FROM customers WHERE name = ?");
                    $stmt->execute([$data[1]]);
                    $customer = $stmt->fetch();
                    
                    if (!$customer) {
                        $stmt = $db->prepare("INSERT INTO customers (name, contact) VALUES (?, ?)");
                        $stmt->execute([$data[1], $data[2]]);
                        $customerId = $db->lastInsertId();
                    } else {
                        $customerId = $customer['id'];
                    }
                    
                    // Insertar crédito
                    $stmt = $db->prepare("
                        INSERT INTO credits 
                        (customer_id, total_amount, num_installments, outstanding_balance, start_date) 
                        VALUES (?, ?, ?, ?, ?)
                    ");
                    
                    $stmt->execute([
                        $customerId,
                        $data[3],
                        $data[4],
                        $data[5],
                        $data[6]
                    ]);
                    
                    $results['success']++;
                } catch (Exception $e) {
                    $results['errors']++;
                    $results['messages'][] = "Error en línea " . ($results['success'] + $results['errors']) . ": " . $e->getMessage();
                }
            }
            
            fclose($handle);
            
            if ($results['errors'] == 0) {
                $db->commit();
            } else {
                $db->rollback();
            }
        }
    } catch (Exception $e) {
        $db->rollback();
        $results['errors']++;
        $results['messages'][] = "Error general: " . $e->getMessage();
    }
    
    return $results;
}

// Función para validar monto
function validateAmount($amount) {
    return is_numeric($amount) && $amount > 0;
}

// Función para validar número de cuotas
function validateInstallments($num) {
    return in_array($num, INSTALLMENT_OPTIONS);
}

// Función para obtener el monto de cuota
function calculateInstallmentAmount($totalAmount, $numInstallments) {
    return round($totalAmount / $numInstallments, 2);
}
?>